@@ -6,24 +6,20 @@
 Ensure that the application content adheres to Splunk standards.
 """
 
-# Python Standard Libraries
 import imghdr
 import logging
 import os
 
-# Third-Party Libraries
 from PIL import Image
 
-# Custom Libraries
 import splunk_appinspect
 
-
 report_display_order = 2
 logger = logging.getLogger(__name__)
 
 
 def _image_attributes(path):
-    """ Helper function to return image metadata"""
+    """Helper function to return image metadata"""
     try:
         img_obj = Image.open(path)
         img_obj.verify()
@@ -34,21 +30,22 @@ def _image_attributes(path):
 
 
 def _verify_image_dimensions(relative_path, app, reporter, max_width, max_height):
-    """ Helper function calling reporter to update the check result"""
+    """Helper function calling reporter to update the check result"""
     file_path = os.path.join(*relative_path)
     full_path = app.get_filename(*relative_path)
     image_attr = _image_attributes(full_path)
     if image_attr is None:
         reporter_output = (
-            "unable to verify the image, the image file is broken. File: {}"
-        ).format(file_path)
+            f"unable to verify the image, the image file is broken. File: {file_path}"
+        )
         reporter.fail(reporter_output, file_path)
     else:
         width, height = image_attr
         if width > max_width or height > max_height:
             reporter_output = (
-                "{} should be {}x{} or less, but was detected as {}x{}. File: {}"
-            ).format(relative_path, max_width, max_height, width, height, file_path)
+                f"{relative_path} should be {max_width}x{max_height} or less, "
+                f"but was detected as {width}x{height}. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
 
 
@@ -60,9 +57,7 @@ def check_app_icon_is_png(app, reporter):
     if app.file_exists(*relative_file_path):
         file_path = os.path.join(*relative_file_path)
         if imghdr.what(app.get_filename(*relative_file_path)) != "png":
-            reporter_output = ("static/appIcon must be a png file. File: {}").format(
-                file_path
-            )
+            reporter_output = f"static/appIcon must be a png file. File: {file_path}"
             reporter.fail(reporter_output, file_path)
     else:
         reporter.fail("static/appIcon.png does not exist.")
@@ -87,9 +82,7 @@ def check_app_icon_2x_is_png(app, reporter):
     if app.file_exists(*relative_file_path):
         file_path = os.path.join(*relative_file_path)
         if imghdr.what(app.get_filename(*relative_file_path)) != "png":
-            reporter_output = ("static/appIcon_2x must be a png file. File: {}").format(
-                file_path
-            )
+            reporter_output = f"static/appIcon_2x must be a png file. File: {file_path}"
             reporter.fail(reporter_output, file_path)
     else:
         reporter.fail("static/appIcon_2x.png does not exist.")
@@ -114,9 +107,7 @@ def check_app_icon_alt_is_png(app, reporter):
     if app.file_exists(*relative_file_path):
         file_path = os.path.join(*relative_file_path)
         if imghdr.what(app.get_filename(*relative_file_path)) != "png":
-            reporter_output = ("static/appIconAlt must be a png file. File: {}").format(
-                file_path
-            )
+            reporter_output = f"static/appIconAlt must be a png file. File: {file_path}"
             reporter.fail(reporter_output, file_path)
     else:
         reporter.not_applicable("static/appIconAlt.png does not exist.")
@@ -142,8 +133,8 @@ def check_app_icon_alt_2x_is_png(app, reporter):
         file_path = os.path.join(*relative_file_path)
         if imghdr.what(app.get_filename(*relative_file_path)) != "png":
             reporter_output = (
-                "static/appIconAlt_2x must be a png file. File: {}"
-            ).format(file_path)
+                f"static/appIconAlt_2x must be a png file. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter.not_applicable("static/appIconAlt_2x.png does not exist.")
@@ -168,9 +159,7 @@ def check_app_logo_is_png(app, reporter):
     if app.file_exists(*relative_file_path):
         file_path = os.path.join(*relative_file_path)
         if imghdr.what(app.get_filename(*relative_file_path)) != "png":
-            reporter_output = ("static/appLogo must be a png file. File: {}").format(
-                file_path
-            )
+            reporter_output = f"static/appLogo must be a png file. File: {file_path}"
             reporter.fail(reporter_output, file_path)
     else:
         reporter.not_applicable("static/appLogo.png does not exist.")
@@ -195,9 +184,7 @@ def check_app_logo_2x_is_png(app, reporter):
     if app.file_exists(*relative_file_path):
         file_path = os.path.join(*relative_file_path)
         if imghdr.what(app.get_filename(*relative_file_path)) != "png":
-            reporter_output = ("static/appLogo_2x must be a png file. File: {}").format(
-                file_path
-            )
+            reporter_output = f"static/appLogo_2x must be a png file. File: {file_path}"
             reporter.fail(reporter_output, file_path)
     else:
         reporter.not_applicable("static/appLogo_2x.png does not exist.")
