@@ -91,10 +91,11 @@ def check_command_scripts_python_version(app, reporter, target_splunk_version):
                     fd = open(python_script_resource.file_path)
                     try:
                         ast.parse(fd.read())
-                    except Exception:
+                    except Exception as ex:
                         reporter.fail(
-                            f"Custom command {command.name} defines a script that is not Python 3 compatible, "
-                            "Please upgrade your Python script to be Python 3 compatible.",
+                            f"Custom command {command.name} defines a script that is not Python 3 compatible. "
+                            f'The error is "{ex}". ',
+                            "Upgrade your Python script to be Python 3 compatible.",
                             os.path.join("bin", command.file_name),
                         )
 
