@@ -128,5 +128,5 @@ def check_html_dashboards(app, reporter):
         "https://dev.splunk.com/enterprise/docs/developapps/visualizedata/updatejquery/"
     )
 
-    for filepath in html_dashboard_files:
-        reporter.warn(message, filepath)
+    for relative_filepath, _ in html_dashboard_files:
+        reporter.warn(message, relative_filepath)
