@@ -9,9 +9,6 @@ import os
 import platform
 import re
 
-import six
-from six import iteritems
-
 import splunk_appinspect
 from splunk_appinspect.check_routine.python_ast_searcher.ast_searcher import AstSearcher
 from splunk_appinspect.check_routine.python_ast_searcher.node_filters import (
@@ -49,18 +46,13 @@ def check_for_hidden_python_files(app, reporter):
     else:
         client = app.python_analyzer_client
         for filepath in client.get_hidden_python_files():
-            if six.PY2:
-                content = open(os.path.join(app.app_temp_dir, filepath), "rU").read()
-            else:
-                import chardet
+            import chardet
 
-                byte_string = open(
-                    os.path.join(app.app_temp_dir, filepath), "rb"
-                ).read()
-                encoding = chardet.detect(byte_string)["encoding"]
-                content = open(
-                    os.path.join(app.app_temp_dir, filepath), "r", encoding=encoding
-                ).read()
+            byte_string = open(os.path.join(app.app_temp_dir, filepath), "rb").read()
+            encoding = chardet.detect(byte_string)["encoding"]
+            content = open(
+                os.path.join(app.app_temp_dir, filepath), "r", encoding=encoding
+            ).read()
             content = re.sub("[\r\n]+", " ", content)
 
             # this check only focus on python template code
@@ -492,7 +484,7 @@ def check_for_plain_text_credentials_in_python(app, reporter):
         all_ast_nodes = set()
         for variable_name, ast_node_set in filter(
             lambda tuple: check_variable_name(tuple[0]),
-            iteritems(ast_info.variable_usage),
+            iter(ast_info.variable_usage.items()),
         ):
             for ast_node in ast_node_set:
                 node_to_name_dict[ast_node] = variable_name
