@@ -5,12 +5,9 @@
 
 REST endpoints are defined in a **restmap.conf** file in the **/default** directory of the app. For more, see [restmap.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Restmapconf).
 """
-
-# Python Standard Library
 import logging
 import os
 
-# Custom Modules
 import splunk_appinspect
 
 logger = logging.getLogger(__name__)
@@ -37,7 +34,7 @@ def check_restmap_conf_exists(app, reporter):
 @splunk_appinspect.cert_version(min="1.1.0")
 def check_rest_handler_scripts_exist(app, reporter):
     """Check that each stanza in restmap.conf has a matching handler script.
-       if not, fail this app.
+    if not, fail this app.
     """
     do_rest_handler_scripts_check(app, reporter.fail)
 
@@ -46,7 +43,7 @@ def check_rest_handler_scripts_exist(app, reporter):
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_rest_handler_scripts_exist_for_cloud(app, reporter):
     """Check that each stanza in restmap.conf has a matching handler script.
-       if not, throw a warning.
+    if not, throw a warning.
     """
     do_rest_handler_scripts_check(app, reporter.fail)
 
@@ -63,9 +60,7 @@ def do_rest_handler_scripts_check(app, reporter_result):
         global_handler = rest_map.global_handler_file()
 
         if global_handler.exists():
-            message = "A global rest handler was found at {}".format(
-                global_handler.file_path
-            )
+            message = f"A global rest handler was found at {global_handler.file_path}"
             logger.info(message)
 
         else:
@@ -83,15 +78,9 @@ def do_rest_handler_scripts_check(app, reporter_result):
                     pass
                 else:
                     reporter_output = (
-                        "Neither the handler or handlerfile specified in the stanza {}"
-                        " was found in app/bin for {}, {} or {}. File: {}, Line: {}."
-                    ).format(
-                        handler.name,
-                        handler.handler_file().file_path,
-                        handler.handler().file_path,
-                        handler.executable_script_file().file_path,
-                        file_path,
-                        handler.lineno,
+                        f"Neither the handler or handlerfile specified in the stanza {handler.name} was found"
+                        f" in app/bin for {handler.handler_file().file_path}, {handler.handler().file_path} or"
+                        f" {handler.executable_script_file().file_path}. File: {file_path}, Line: {handler.lineno}."
                     )
                     reporter_result(reporter_output, file_path, handler.lineno)
     else:
@@ -103,8 +92,7 @@ def do_rest_handler_scripts_check(app, reporter_result):
 )
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_rest_handler_python_executable_exists(app, reporter):
-    """Check that python version is python3 for executables in restmap.conf.
-    """
+    """Check that python version is python3 for executables in restmap.conf."""
     rest_map = app.get_rest_map()
     file_path = os.path.join("default", "restmap.conf")
     if rest_map.configuration_file_exists():
@@ -120,9 +108,9 @@ def check_rest_handler_python_executable_exists(app, reporter):
             # Verify python rest handler.
             if not handler.python_version or handler.python_version != "python3":
                 reporter_message = (
-                    "The handler of stanza [{}] should be `python3` executable. "
-                    "File: {}, Line: {}."
-                ).format(handler.name, file_path, handler.lineno)
+                    f"The handler of stanza [{handler.name}] should be `python3` executable. "
+                    f"File: {file_path}, Line: {handler.lineno}."
+                )
                 reporter.fail(reporter_message, file_path, handler.lineno)
     else:
         reporter_output = "No restmap.conf file exists."
