@@ -8,8 +8,6 @@ Saved searches are defined in a **savedsearches.conf** file located in the **/de
 import logging
 import os
 
-from six import iteritems
-
 import splunk_appinspect
 from splunk_appinspect.cron_expression import CronExpression
 from splunk_appinspect.splunk import normalizeBoolean
@@ -79,7 +77,7 @@ def check_for_emails_in_saved_search(app, reporter):
     if saved_searches.configuration_file_exists():
         file_path = os.path.join("default", "savedsearches.conf")
         for search in saved_searches.searches():
-            for key, value in iteritems(search.args):
+            for key, value in iter(search.args.items()):
                 if key == "action.email.to":
                     reporter_output = (
                         f"The saved search {search.name} has specified the"
