@@ -3,25 +3,22 @@
 """
 ### Security vulnerabilities
 """
-
-# Python Standard Libraries
 import logging
 import os
+import platform
 import re
 
-# Custom Libraries
-import platform
 import splunk_appinspect
-
 from splunk_appinspect.check_routine.python_ast_searcher.ast_searcher import AstSearcher
+from splunk_appinspect.python_analyzer.ast_types import AstVariable
+from splunk_appinspect.python_modules_metadata.metadata_common import metadata_consts
 from splunk_appinspect.python_modules_metadata.python_modules_metadata_store import (
     metadata_store,
 )
-from splunk_appinspect.python_modules_metadata.metadata_common import metadata_consts
-from splunk_appinspect.python_analyzer.ast_types import AstVariable
-
-from splunk_appinspect.regex_matcher import SecretDisclosureInAllFilesMatcher
-from splunk_appinspect.regex_matcher import SecretDisclosureInNonPythonFilesMatcher
+from splunk_appinspect.regex_matcher import (
+    SecretDisclosureInAllFilesMatcher,
+    SecretDisclosureInNonPythonFilesMatcher,
+)
 
 logger = logging.getLogger(__name__)
 report_display_order = 5
@@ -47,8 +44,9 @@ def check_for_pexpect(app, reporter):
     for match in app.search_for_pattern("pexpect.run", types=[".py"]):
         filename, line = match[0].rsplit(":", 1)
         reporter_output = (
-            "Possible use of pexpect- detected in {}. " "File: {}, Line: {}."
-        ).format(match[0], filename, line)
+            f"Possible use of pexpect- detected in {match[0]}. "
+            f"File: {filename}, Line: {line}."
+        )
         reporter.manual_check(reporter_output, filename, line)
 
 
@@ -80,10 +78,10 @@ def check_for_secret_disclosure(app, reporter):
         reporter_output = (
             "The following line will be inspected during code review. "
             "Possible secret disclosure found."
-            " Match: {}"
-            " File: {}"
-            " Line: {}"
-        ).format(result, file_path, lineno)
+            f" Match: {result}"
+            f" File: {file_path}"
+            f" Line: {lineno}"
+        )
         reporter.manual_check(reporter_output, file_path, lineno)
 
     # regex patterns target non-python files, python files would be covered in check_python_files
@@ -102,10 +100,10 @@ def check_for_secret_disclosure(app, reporter):
         reporter_output = (
             "The following line will be inspected during code review."
             "Possible secret disclosure found."
-            " Match: {}"
-            " File: {}"
-            " Line: {}"
-        ).format(result, file_path, lineno)
+            f" Match: {result}"
+            f" File: {file_path}"
+            f" Line: {lineno}"
+        )
         reporter.manual_check(reporter_output, file_path, lineno)
 
     # process the messages_in_props_or_transforms_file: {file_path: {lineno: [result1, result2]}}
@@ -119,10 +117,10 @@ def check_for_secret_disclosure(app, reporter):
                 reporter_output = (
                     "The following line will be inspected during code review."
                     "Possible secret disclosure found."
-                    " Match: {}"
-                    " File: {}"
-                    " Line: {}"
-                ).format(result, file_path, lineno)
+                    f" Match: {result}"
+                    f" File: {file_path}"
+                    f" Line: {lineno}"
+                )
                 reporter.manual_check(reporter_output, file_path, lineno)
 
 
@@ -213,7 +211,7 @@ def _secret_disclosure_commands_whitelist(file_path, messages):
 def _combine_messages_in_special_files(
     file_path, lineno, result, messages_in_special_files
 ):
-    """ Combine the messages and update the messages_in_special_files
+    """Combine the messages and update the messages_in_special_files
     :param file_path:
     :param lineno:
     :param result:
@@ -253,16 +251,9 @@ def check_for_sensitive_info_in_url(app, reporter):
             for p_match in rx.finditer(match[1].group()):
                 description = p_match.group()
                 reporter_output = (
-                    "Possible sensitive information being exposed via URL in {}: {}."
-                    " File: {}, Line: {}."
-                ).format(
-                    match[0],
-                    # match[1].group(),
-                    description,
-                    filename,
-                    line,
+                    f"Possible sensitive information being exposed via URL in {match[0]}: {description}."
+                    f" File: {filename}, Line: {line}."
                 )
-
                 reporter.warn(reporter_output, filename, line)
 
 
@@ -273,8 +264,9 @@ def check_for_vbs_command_injection(app, reporter):
     for match in app.search_for_pattern("Shell.*Exec", types=[".vbs"]):
         filename, line = match[0].rsplit(":", 1)
         reporter_output = (
-            "Possible command injection in {}: {}." " File: {}, Line: {}."
-        ).format(match[0], match[1].group(), filename, line)
+            f"Possible command injection in {match[0]}: {match[1].group()}. "
+            f"File: {filename}, Line: {line}."
+        )
         reporter.manual_check(reporter_output, filename, line)
 
 
@@ -287,8 +279,9 @@ def check_for_command_injection_through_env_vars(app, reporter):
     ):
         filename, line = match[0].rsplit(":", 1)
         reporter_output = (
-            "Possible command injection in {}: {}." " File: {}, Line: {}."
-        ).format(match[0], match[1].group(), filename, line)
+            f"Possible command injection in {match[0]}: {match[1].group()}. "
+            f"File: {filename}, Line: {line}."
+        )
         reporter.manual_check(reporter_output, filename, line)
 
 
@@ -353,8 +346,9 @@ def check_for_stacktrace_returned_to_user(app, reporter):
     for match in app.search_for_pattern("format_exc", types=[".py"]):
         filename, line = match[0].rsplit(":", 1)
         reporter_output = (
-            "Stacktrace being formatted in {}: {}." "File: {}, Line: {}."
-        ).format(match[0], match[1].group(), filename, line)
+            f"Stacktrace being formatted in {match[0]}: {match[1].group()}. "
+            f"File: {filename}, Line: {line}."
+        )
         reporter.manual_check(reporter_output, filename, line)
 
 
@@ -375,24 +369,25 @@ def check_for_environment_variable_use_in_python(app, reporter):
     for match in app.search_for_pattern(env_manual_regex, types=[".py"]):
         filename, line = match[0].rsplit(":", 1)
         reporter_output = (
-            "Environment variable being used in {}: {}." "File: {}, Line: {}."
-        ).format(match[0], match[1].group(), filename, line)
+            f"Environment variable being used in {match[0]}: {match[1].group()}. "
+            f"File: {filename}, Line: {line}."
+        )
         reporter.manual_check(reporter_output, filename, line)
     # Fail for use of `os.putenv` / `os.unsetenv` in any scenario
     env_set_regex = r"(os[\s]*\.[\s]*putenv|os[\s]*\.[\s]*unsetenv)"
     for match in app.search_for_pattern(env_set_regex, types=[".py"]):
         filename, line = match[0].rsplit(":", 1)
         reporter_output = (
-            "Environment variable manipulation detected in {}: {}."
-            "File: {}, Line: {}."
-        ).format(match[0], match[1].group(), filename, line)
+            f"Environment variable manipulation detected in {match[0]}: {match[1].group()}."
+            f"File: {filename}, Line: {line}."
+        )
         reporter.fail(reporter_output, filename, line)
 
 
 @splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.2")
 def check_symlink_outside_app(app, reporter):
-    """ Check no symlink points to the file outside this app """
+    """Check no symlink points to the file outside this app"""
     if platform.system() == "Windows":
         reporter_output = "Please run AppInspect using another OS to enable this check. Or use AppInspect API."
         reporter.warn(reporter_output)
@@ -411,7 +406,8 @@ def check_symlink_outside_app(app, reporter):
                 # link to outer path
                 if not link_to_absolute_path.startswith(app_root_dir):
                     reporter_output = (
-                        "Link file found in path: {}. The file links to a "
-                        "path outside of this app, the link path is: {}. File: {}"
-                    ).format(full_file_path, link_to_absolute_path, app_file_path)
+                        f"Link file found in path: {full_file_path}. The file links to a path "
+                        f"outside of this app, the link path is: {link_to_absolute_path}. "
+                        f"File: {app_file_path}"
+                    )
                     reporter.fail(reporter_output, app_file_path)
