@@ -2,18 +2,14 @@
 """
 Splunk AppInspect certification events listeners/handlers for test mode
 """
-
-# Python Standard Libraries
 import logging
 import sys
 
-# Third-Party Libraries
 import click
 
-# Custom Libraries
 import splunk_appinspect
-from . import listener
 
+from . import listener
 
 logger = logging.getLogger(__name__)
 
@@ -49,15 +45,12 @@ class DotStatusListener(listener.Listener):
 
         :param app (App) The app object representing the Splunk Application.
         """
-        command_line_output = ("Validating: {} Version: {}").format(
-            app.name, app.version
-        )
+        command_line_output = f"Validating: {app.name} Version: {app.version}"
         click.echo(command_line_output)
 
     @staticmethod
     def on_enable_python_analyzer():
-        """Returns None
-        """
+        """Returns None"""
         click.echo("Enable Python analyzer.")
 
     def on_finish_check(self, check, reporter):
@@ -112,7 +105,7 @@ class DotStatusListener(listener.Listener):
             message_types=message_types,
         )
         click.echo("\n")
-        summary_header = "{} Report Summary".format(app.name)
+        summary_header = f"{app.name} Report Summary"
         splunk_appinspect.command_line_helpers.output_summary(
             application_validation_report.get_summary(), summary_header=summary_header
         )
