@@ -10,9 +10,6 @@ import platform
 import shutil
 from lib2to3.main import main as exec_two_to_three
 
-import six
-from six import iteritems
-
 from splunk_appinspect.python_analyzer import ast_types, utilities
 
 if not platform.system() == "Windows":
@@ -186,15 +183,15 @@ class FileDepManager(object):
         stack = []
         changeable_in_degree = {}
         # initialize in degree with default value
-        for _, file_node in iteritems(self._file_pool):
+        for _, file_node in iter(self._file_pool.items()):
             changeable_in_degree[file_node] = file_node.in_degree
         # remove circular nodes' out edges
-        for _, file_node in iteritems(self._file_pool):
+        for _, file_node in iter(self._file_pool.items()):
             if file_node in self._python_files_in_circular_dependency:
                 for child_node in file_node.iter_child():
                     changeable_in_degree[child_node] -= 1
         # start topological sort
-        for _, file_node in iteritems(self._file_pool):
+        for _, file_node in iter(self._file_pool.items()):
             if changeable_in_degree[file_node] == 0 and (
                 file_node not in self._python_files_in_circular_dependency
             ):
@@ -239,7 +236,7 @@ class FileDepManager(object):
                     self._circular_dependency.append(cur_scc)
                     self._python_files_in_circular_dependency |= set(cur_scc)
 
-        for _, file_node in iteritems(self._file_pool):
+        for _, file_node in iter(self._file_pool.items()):
             if file_node not in visited:
                 dfs(file_node)
 
@@ -256,35 +253,29 @@ class FileDepManager(object):
         try:
             deps = utilities.find_imports(filepath, self.libs)
         except SyntaxError:
-            if six.PY2:
+            # try to run 2to3 in python3 interpreter
+            try:
+                self._preprocess_file(filepath)
+                if (
+                    not eval(os.getenv("APPINSPECT_DISABLE_2TO3_CONCURRENCY", "False"))
+                    and multiprocessing.cpu_count() > 1
+                    and platform.system() != "Windows"
+                ):
+
+                    exec_two_to_three(
+                        fixer_pkg="lib2to3.fixes",
+                        args=["-w", filepath, "--no-diffs", "-j", "2"],
+                    )
+                else:
+                    exec_two_to_three(
+                        fixer_pkg="lib2to3.fixes",
+                        args=["-w", filepath, "--no-diffs"],
+                    )
+                # retry find_imports again
+                deps = utilities.find_imports(filepath, self.libs)
+            except Exception:
                 self._syntax_error_file.add(filepath)
                 return None
-            else:
-                # try to run 2to3 in python3 interpreter
-                try:
-                    self._preprocess_file(filepath)
-                    if (
-                        not eval(
-                            os.getenv("APPINSPECT_DISABLE_2TO3_CONCURRENCY", "False")
-                        )
-                        and multiprocessing.cpu_count() > 1
-                        and platform.system() != "Windows"
-                    ):
-
-                        exec_two_to_three(
-                            fixer_pkg="lib2to3.fixes",
-                            args=["-w", filepath, "--no-diffs", "-j", "2"],
-                        )
-                    else:
-                        exec_two_to_three(
-                            fixer_pkg="lib2to3.fixes",
-                            args=["-w", filepath, "--no-diffs"],
-                        )
-                    # retry find_imports again
-                    deps = utilities.find_imports(filepath, self.libs)
-                except Exception:
-                    self._syntax_error_file.add(filepath)
-                    return None
         except (TypeError, ValueError):
             # TypeError in python2, ValueError in python3
             self._null_byte_error_file.add(filepath)
@@ -357,50 +348,45 @@ class FileDepManager(object):
                             self.add_file(file_path)
                         except Exception:
                             # try 2to3 when py version is three
-                            if not six.PY2:
-                                try:
-                                    self._preprocess_file(file_path)
-                                    if (
-                                        not eval(
-                                            os.getenv(
-                                                "APPINSPECT_DISABLE_2TO3_CONCURRENCY",
-                                                "False",
-                                            )
+                            try:
+                                self._preprocess_file(file_path)
+                                if (
+                                    not eval(
+                                        os.getenv(
+                                            "APPINSPECT_DISABLE_2TO3_CONCURRENCY",
+                                            "False",
                                         )
-                                        and multiprocessing.cpu_count() > 1
-                                        and platform.system() != "Windows"
-                                    ):
+                                    )
+                                    and multiprocessing.cpu_count() > 1
+                                    and platform.system() != "Windows"
+                                ):
 
-                                        exec_two_to_three(
-                                            fixer_pkg="lib2to3.fixes",
-                                            args=[
-                                                "-w",
-                                                file_path,
-                                                "--no-diffs",
-                                                "-j",
-                                                "2",
-                                            ],
-                                        )
-                                    else:
-                                        exec_two_to_three(
-                                            fixer_pkg="lib2to3.fixes",
-                                            args=["-w", file_path, "--no-diffs"],
-                                        )
+                                    exec_two_to_three(
+                                        fixer_pkg="lib2to3.fixes",
+                                        args=[
+                                            "-w",
+                                            file_path,
+                                            "--no-diffs",
+                                            "-j",
+                                            "2",
+                                        ],
+                                    )
+                                else:
+                                    exec_two_to_three(
+                                        fixer_pkg="lib2to3.fixes",
+                                        args=["-w", file_path, "--no-diffs"],
+                                    )
 
-                                    ast.parse(open(file_path, mode="rb").read())
-                                    counter += 1
-                                    self.add_file(file_path)
-                                except Exception:
-                                    # 2to3 parser and python3 parser are more stricter
-                                    # stored in syntax error file to guarantee we won't leave it out
-                                    if file_path.endswith(".py"):
-                                        self._syntax_error_file.add(file_path)
-                                    else:
-                                        self._hidden_python_file.add(file_path)
-                            else:
-                                # python2 parser is more tolerant, so we use hidden python file here
-                                # template code will be covered in `check_for_hidden_python_files`
-                                self._hidden_python_file.add(file_path)
+                                ast.parse(open(file_path, mode="rb").read())
+                                counter += 1
+                                self.add_file(file_path)
+                            except Exception:
+                                # 2to3 parser and python3 parser are more stricter
+                                # stored in syntax error file to guarantee we won't leave it out
+                                if file_path.endswith(".py"):
+                                    self._syntax_error_file.add(file_path)
+                                else:
+                                    self._hidden_python_file.add(file_path)
 
         self._populate_circular_dependency()
         return counter
