@@ -1,8 +1,12 @@
 """
 Execute xml pulldom commands, the pulldom is support for building partial DOM trees
 """
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.FILE_READ_AND_WRITE)
@@ -11,4 +15,3 @@ def parse():
     Parse a file or file-like object.
     """
     pass
-
